﻿Imports MyERP2.BL
''' <summary>
''' This singleton class provides all available authorizations stored as Authorization Item
''' </summary>
Public Class AuthorizationRepositoryCls

    Private Shared ReadOnly vInstance As New Lazy(Of AuthorizationRepositoryCls)(Function() New AuthorizationRepositoryCls(), Threading.LazyThreadSafetyMode.ExecutionAndPublication)

    Public Shared ReadOnly Property Instance As AuthorizationRepositoryCls
        Get
            Return vInstance.Value
        End Get
    End Property

    Dim vAuthorizations As New List(Of AuthorizationItem)

    Public Property Authorizations As List(Of AuthorizationItem)
        Get
            Return vAuthorizations
        End Get
        Set(value As List(Of AuthorizationItem))
            vAuthorizations = value
        End Set
    End Property

    Sub New()
        GetAdministrationRights()
        GetAccoutingRights()
        GetArticleResourcesRights()
        GetSalesRights()
        GetPurchaseRights()
        GetProductionRights()
    End Sub

    'For better handling the code the different available Items are not stored directly into the list, they are loaded during the sub new event.
#Region "Administration Rights"
    Private Sub GetAdministrationRights()
        Dim vCat As String = "Administration"
        With Authorizations
            'Numberranges
            .Add(New AuthorizationItem(vCat, "access_numberranges", "Nummernkreise öffnen", "Berechtigung zum Öffnen des Moduls Nummernkreise"))
            .Add(New AuthorizationItem(vCat, "add_numberranges", "Nummernkreis hinzufügen", "Berechtigung zum Erstellen eines Nummernkreises"))
            .Add(New AuthorizationItem(vCat, "edit_numberranges", "Nummernkreis editieren", "Berechtigung zum Ändern eines Nummernkreises"))
            .Add(New AuthorizationItem(vCat, "delete_numberranges", "Nummernkreis löschen", "Berechtigung zum Löschen eines Nummernkreises"))
            'Units
            .Add(New AuthorizationItem(vCat, "access_units", "Einheiten öffnen", "Berechtigung zum Öffnen des Moduls Einheiten"))
            .Add(New AuthorizationItem(vCat, "add_units", "Einheiten hinzufügen", "Berechtigung zum Erstellen einer Einheit"))
            .Add(New AuthorizationItem(vCat, "edit_units", "Einheiten editieren", "Berechtigung zum Ändern einer Einheit"))
            .Add(New AuthorizationItem(vCat, "delete_units", "Einheiten löschen", "Berechtigung zum Löschen einer Einheit"))
            'User Management
            .Add(New AuthorizationItem(vCat, "access_users", "Benutzerverwaltung öffnen", "Berechtigung zum Öffnen des Moduls Benutzerverwaltung"))
            .Add(New AuthorizationItem(vCat, "add_users", "Benutzer hinzufügen", "Berechtigung zum Erstellen eines Benutzers"))
            .Add(New AuthorizationItem(vCat, "edit_users", "Benutzer editieren", "Berechtigung zum Ändern eines Benutzers"))
            .Add(New AuthorizationItem(vCat, "delete_users", "Benutzer löschen", "Berechtigung zum Löschen eines Benutzers"))
            'Usergroups
            .Add(New AuthorizationItem(vCat, "access_usergroups", "Benutzergruppenverwaltung öffnen", "Berechtigung zum Öffnen des Moduls Benutzergruppenverwaltung"))
            .Add(New AuthorizationItem(vCat, "add_usergroups", "Benutzergruppe hinzufügen", "Berechtigung zum Erstellen einer Benutzergruppe"))
            .Add(New AuthorizationItem(vCat, "edit_usergroups", "Benutzergruppe editieren", "Berechtigung zum Ändern einer Benutzergruppe"))
            .Add(New AuthorizationItem(vCat, "delete_usergroups", "Benutzergruppe löschen", "Berechtigung zum Löschen einer Benutzergruppe"))
            'Notes
            .Add(New AuthorizationItem(vCat, "access_notes", "Notizenverwaltung öffnen", "Berechtigung zum Öffnen des Moduls Notizen"))
            .Add(New AuthorizationItem(vCat, "add_notes", "Notiz hinzufügen", "Berechtigung zum Erstellen einer Notiz"))
            .Add(New AuthorizationItem(vCat, "edit_notes", "Notiz editieren", "Berechtigung zum Ändern einer Notiz"))
            .Add(New AuthorizationItem(vCat, "delete_notes", "Notiz löschen", "Berechtigung zum Löschen einer Notiz"))
            'Languages
            .Add(New AuthorizationItem(vCat, "access_language", "Sprachenverwaltung öffnen", "Berechtigung zum Öffnen des Moduls Sprachen"))
            .Add(New AuthorizationItem(vCat, "add_language", "Sprache hinzufügen", "Berechtigung zum Erstellen einer Sprache"))
            .Add(New AuthorizationItem(vCat, "edit_language", "Sprache editieren", "Berechtigung zum Ändern einer Sprache"))
            .Add(New AuthorizationItem(vCat, "delete_language", "Sprache löschen", "Berechtigung zum Löschen einer Sprache"))
        End With
    End Sub
#End Region

#Region "Accouting"
    Private Sub GetAccoutingRights()
        Dim vCat As String = "Accounting"
        With Authorizations
            'Currencies
            .Add(New AuthorizationItem(vCat, "access_currencies", "Währungsverwaltung öffnen", "Berechtigung zum Öffnen des Moduls Währungsverwaltung"))
            .Add(New AuthorizationItem(vCat, "add_currencies", "Währung hinzufügen", "Berechtigung zum Erstellen einer Währung"))
            .Add(New AuthorizationItem(vCat, "edit_currencies", "Währung editieren", "Berechtigung zum Ändern einer Währung"))
            .Add(New AuthorizationItem(vCat, "delete_currencies", "Währung löschen", "Berechtigung zum Löschen einer Währung"))
            'Legal Forms
            .Add(New AuthorizationItem(vCat, "access_legalforms", "Rechtsformenverwaltung öffnen", "Berechtigung zum Öffnen des Moduls Rechtsformenverwaltung"))
            .Add(New AuthorizationItem(vCat, "add_legalforms", "Rechtsform hinzufügen", "Berechtigung zum Erstellen einer Rechtsform"))
            .Add(New AuthorizationItem(vCat, "edit_legalforms", "Rechtsform editieren", "Berechtigung zum Ändern einer Rechtsform"))
            .Add(New AuthorizationItem(vCat, "delete_legalforms", "Rechtsform löschen", "Berechtigung zum Löschen einer Rechtsform"))
            'VAT Groups
            .Add(New AuthorizationItem(vCat, "access_vatgroups", "Mehrwertsteuergruppenenverwaltung öffnen", "Berechtigung zum Öffnen des Moduls Mehrwertsteuergruppenenverwaltung"))
            .Add(New AuthorizationItem(vCat, "add_vatgroups", "Mehrwertsteuergruppe hinzufügen", "Berechtigung zum Erstellen einer Mehrwertsteuergruppe"))
            .Add(New AuthorizationItem(vCat, "edit_vatgroups", "Mehrwertsteuergruppe editieren", "Berechtigung zum Ändern einer Mehrwertsteuergruppe"))
            .Add(New AuthorizationItem(vCat, "delete_vatgroups", "Mehrwertsteuergruppe löschen", "Berechtigung zum Löschen einer Mehrwertsteuergruppe"))
        End With
    End Sub
#End Region

#Region "Article & Resources"
    Private Sub GetArticleResourcesRights()
        Dim vCat As String = "Articles/Resources"
        With Authorizations
            'Articles
            .Add(New AuthorizationItem(vCat, "access_articles", "Artikel öffnen", "Berechtigung zum Öffnen des Moduls Artikel"))
            .Add(New AuthorizationItem(vCat, "add_articles", "Artikel hinzufügen", "Berechtigung zum Erstellen eines Artikels"))
            .Add(New AuthorizationItem(vCat, "edit_articles", "Artikel editieren", "Berechtigung zum Ändern eines Artikels"))
            .Add(New AuthorizationItem(vCat, "delete_articles", "Artikel löschen", "Berechtigung zum Löschen eines Artikels"))
        End With
    End Sub

#End Region

#Region "Sales"
    Private Sub GetSalesRights()
        Dim vCat As String = "Sales"
        With Authorizations
            'CRM-Contacts
            .Add(New AuthorizationItem(vCat, "access_contacts", "CRM Kontakte öffnen", "Berechtigung zum Öffnen des Moduls CRM Kontakte"))
            .Add(New AuthorizationItem(vCat, "add_contacts", "CRM Kontakt hinzufügen", "Berechtigung zum Erstellen eines CRM Kontakt"))
            .Add(New AuthorizationItem(vCat, "edit_contacts", "CRM Kontakt editieren", "Berechtigung zum Ändern eines CRM Kontakt"))
            .Add(New AuthorizationItem(vCat, "delete_contacts", "CRM Kontakt löschen", "Berechtigung zum Löschen eines CRM Kontakt"))
            'Discount Groups
            .Add(New AuthorizationItem(vCat, "access_discountgroups", "Rabattgruppen öffnen", "Berechtigung zum Öffnen des Moduls Rabattgruppen"))
            .Add(New AuthorizationItem(vCat, "add_discountgroups", "Rabattgruppe hinzufügen", "Berechtigung zum Erstellen einer Rabattgruppe"))
            .Add(New AuthorizationItem(vCat, "edit_discountgroups", "Rabattgruppe editieren", "Berechtigung zum Ändern einer Rabattgruppe"))
            .Add(New AuthorizationItem(vCat, "delete_discountgroups", "Rabattgruppe löschen", "Berechtigung zum Löschen einer Rabattgruppe"))
            'Sales Prices
            .Add(New AuthorizationItem(vCat, "access_salesprices", "Verkaufspreise öffnen", "Berechtigung zum Öffnen des Moduls Verkaufspreise"))
            .Add(New AuthorizationItem(vCat, "add_salesprices", "Verkaufspreis hinzufügen", "Berechtigung zum Erstellen eines Verkaufspreises"))
            .Add(New AuthorizationItem(vCat, "edit_salesprices", "Verkaufspreis editieren", "Berechtigung zum Ändern eines Verkaufspreises"))
            .Add(New AuthorizationItem(vCat, "delete_salesprices", "Verkaufspreis löschen", "Berechtigung zum Löschen eines Verkaufspreises"))
            'Sales Texts
            .Add(New AuthorizationItem(vCat, "access_article_salestexts", "Artikel Verkaufstexte öffnen", "Berechtigung zum Öffnen des Moduls Artikel Verkaufstexte"))
            .Add(New AuthorizationItem(vCat, "add_article_salestexts", "Artikel Verkaufstexte hinzufügen", "Berechtigung zum Erstellen eines Artikel Verkaufstextes"))
            .Add(New AuthorizationItem(vCat, "edit_article_salestexts", "Artikel Verkaufstexte editieren", "Berechtigung zum Ändern eines Artikel Verkaufstextes"))
            .Add(New AuthorizationItem(vCat, "delete_article_salestexts", "Artikel Verkaufstexte löschen", "Berechtigung zum Löschen eines Artikel Verkaufstextes"))
            'Article Text Repository Sales
            .Add(New AuthorizationItem(vCat, "access_description_sales", "Artikelbeschreibung Verkauf öffnen", "Berechtigung zum Öffnen des Moduls Verkaufsartikelbeschreibung"))
            .Add(New AuthorizationItem(vCat, "add_description_sales", "Artikelbeschreibung Verkauf hinzufügen", "Berechtigung zum Erstellen einer Verkaufsartikelbeschreibung "))
            .Add(New AuthorizationItem(vCat, "edit_description_sales", "Artikelbeschreibung Verkauf editieren", "Berechtigung zum Ändern einer Verkaufsartikelbeschreibung"))
            .Add(New AuthorizationItem(vCat, "delete_description_sales", "Artikelbeschreibung Verkauf löschen", "Berechtigung zum Löschen einer Verkaufsartikelbeschreibung"))
        End With
    End Sub
#End Region

#Region "Purchase"
    Private Sub GetPurchaseRights()
        Dim vCat As String = "Purchase"
        With Authorizations
            'Suppliers
            .Add(New AuthorizationItem(vCat, "access_suppliers", "Lieferanten öffnen", "Berechtigung zum Öffnen des Moduls Lieferanten"))
            .Add(New AuthorizationItem(vCat, "add_suppliers", "Lieferanten hinzufügen", "Berechtigung zum Erstellen eines Lieferanten"))
            .Add(New AuthorizationItem(vCat, "edit_suppliers", "Lieferanten editieren", "Berechtigung zum Ändern eines Lieferanten"))
            .Add(New AuthorizationItem(vCat, "delete_suppliers", "Lieferanten löschen", "Berechtigung zum Löschen eines Lieferanten"))
            'Purchase Texts
            .Add(New AuthorizationItem(vCat, "access_article_purchasetexts", "Artikel Einkaufstexte öffnen", "Berechtigung zum Öffnen des Moduls Artikel Einkaufstexte"))
            .Add(New AuthorizationItem(vCat, "add_article_purchasetexts", "Artikel Einkaufstexte hinzufügen", "Berechtigung zum Erstellen eines Artikel Einkaufstextes"))
            .Add(New AuthorizationItem(vCat, "edit_article_purchasetexts", "Artikel Einkaufstexte editieren", "Berechtigung zum Ändern eines Artikel Einkaufstextes"))
            .Add(New AuthorizationItem(vCat, "delete_article_purchasetexts", "Artikel Einkaufstexte löschen", "Berechtigung zum Löschen eines Artikel Einkaufstextes"))
            'Article Text Repository Purchase
            .Add(New AuthorizationItem(vCat, "access_description_purchase", "Artikelbeschreibung Einkauf öffnen", "Berechtigung zum Öffnen des Moduls Einkaufsartikelbeschreibung"))
            .Add(New AuthorizationItem(vCat, "add_description_purchase", "Artikelbeschreibung Einkauf hinzufügen", "Berechtigung zum Erstellen einer Einkaufsartikelbeschreibung "))
            .Add(New AuthorizationItem(vCat, "edit_description_purchase", "Artikelbeschreibung Einkauf editieren", "Berechtigung zum Ändern einer Einkaufsartikelbeschreibung"))
            .Add(New AuthorizationItem(vCat, "delete_description_purchase", "Artikelbeschreibung Einkauf löschen", "Berechtigung zum Löschen einer Einkaufsartikelbeschreibung"))
        End With
    End Sub
#End Region

#Region "Production"
    Private Sub GetProductionRights()
        Dim vCat As String = "Production"
        With Authorizations
            'Article Production Texts
            .Add(New AuthorizationItem(vCat, "access_article_productiontexts", "Artikel Produktionstexte öffnen", "Berechtigung zum Öffnen des Moduls Artikel Produktionstexte"))
            .Add(New AuthorizationItem(vCat, "add_article_productiontexts", "Artikel Produktionstexte hinzufügen", "Berechtigung zum Erstellen eines Artikel Produktionstextes"))
            .Add(New AuthorizationItem(vCat, "edit_article_productiontexts", "Artikel Produktionstexte editieren", "Berechtigung zum Ändern eines Artikel Produktionstextes"))
            .Add(New AuthorizationItem(vCat, "delete_article_productiontexts", "Artikel Produktionstexte löschen", "Berechtigung zum Löschen eines Artikel Produktionstextes"))
            'Article Text Repository Production
            .Add(New AuthorizationItem(vCat, "access_description_production", "Artikelbeschreibung Produktion öffnen", "Berechtigung zum Öffnen des Moduls Produktionsartikelbeschreibung"))
            .Add(New AuthorizationItem(vCat, "add_description_production", "Artikelbeschreibung Produktion hinzufügen", "Berechtigung zum Erstellen einer Produktionsartikelbeschreibung "))
            .Add(New AuthorizationItem(vCat, "edit_description_production", "Artikelbeschreibung Produktion editieren", "Berechtigung zum Ändern einer Produktionsartikelbeschreibung"))
            .Add(New AuthorizationItem(vCat, "delete_description_production", "Artikelbeschreibung Produktion löschen", "Berechtigung zum Löschen einer Produktionsartikelbeschreibung"))
        End With
    End Sub
#End Region



End Class