﻿Imports System.Configuration
Imports System.Data.SqlClient
Imports System.Windows.Threading
Imports Model.MyERP2Model
Imports MyERP2.BL
Imports MyERP2.BL.Persistence
Imports MyERP2.DBContext
Imports ViewModel.ViewModel

Class Application
    Private Sub Application_Startup(sender As Object, e As StartupEventArgs) Handles Me.Startup
    End Sub

    Protected Overrides Sub OnStartup(e As StartupEventArgs)
        MyBase.OnStartup(e)

        Dim vLogin As New LoginFrm
        vLogin.ShowDialog()
        If vLogin.DialogResult Then
            'Attemp to login the user
            'Define the ConnectionString and Store it to a singletonclass:
            Dim vVM As LoginVM = DirectCast(vLogin.DataContext, LoginVM)
            If ConnectionStringBuilder(vVM.SelectedServer, vVM.SelectedDatabase, vVM.Username, vVM.Password) = False Then
                MessageBox.Show("Verbindungszeichenfolge konnte nicht erstellt werden", "Fehler", MessageBoxButton.OK, MessageBoxImage.Error)
                Environment.Exit(0)
            End If
        Else
            'Cancel start
            Environment.Exit(0)
        End If

        'Now that we have all credentials of the current user and a connectionstring built we can try to connect with the dabase server if the user is not allowed to login we will find out now:

        Using _UnitOfWork As New UnitOfWork()
            Dim vVM As LoginVM = DirectCast(vLogin.DataContext, LoginVM)
            Dim vUsers As List(Of User) = _UnitOfWork.UsersRepo.FindBy(Function(x) x.DeletedFlag = False AndAlso x.Username.ToLower = vVM.Username.ToLower).ToList
            If vUsers Is Nothing Then
                MessageBox.Show("Fehler beim Login")
            ElseIf vUsers.Count = 0 Then
                MessageBox.Show("Kein Benutzer gefunden")
            ElseIf vUsers.Count = 1 Then
                CurrentlyLoggedinUser.Instance().UserID = vUsers.First.Id
                'Everything is ok because the model is defined as friend in the viewmodel the passing of the currently logged on user happens during init of mainviewmodel
                Debug.Print("Login OK")
                Dim w = New MainWindow
                MainWindow = w
                With w
                    .WindowState = WindowState.Maximized
                    .ShowActivated = True
                    .Show()
                    .Activate()
                    .BringIntoView()
                End With
            Else
                MessageBox.Show("Kein Benutzer gefunden")
            End If
        End Using

    End Sub

    Private Sub Application_Exit(sender As Object, e As ExitEventArgs) Handles Me.[Exit]

    End Sub

    Private Sub Application_DispatcherUnhandledException(sender As Object, e As DispatcherUnhandledExceptionEventArgs) Handles Me.DispatcherUnhandledException

    End Sub

    ''' <summary>
    ''' Function creates a connectionstring with the given parameters
    ''' Note: all parameters are mandatory
    ''' Created ConnectionString is stored in the singleton CurrentSessionsSettingsCls Class in Property ConnectionString
    ''' </summary>
    ''' <param name="vServer">Name of the database server</param>
    ''' <param name="vDatabase">Name of the database on the server</param>
    ''' <param name="vUsername">SQL Username to connect</param>
    ''' <param name="vPwd">Password of the user</param>
    ''' <returns>True => Connectionstring was successfully build False => something went wrong</returns>
    Public Function ConnectionStringBuilder(vServer As String, vDatabase As String, vUsername As String, vPwd As String) As Boolean
        If vServer = "" OrElse vDatabase = "" OrElse vUsername = "" OrElse vPwd = "" Then Return False
        Dim vSettings As ConnectionStringSettings = ConfigurationManager.ConnectionStrings("DatabaseConnection")
        If vSettings IsNot Nothing Then
            Dim vBaseConnectionString As String = vSettings.ConnectionString
            Dim vBuilder As SqlConnectionStringBuilder = New SqlConnectionStringBuilder(vBaseConnectionString) With {
                .DataSource = vServer,
                .InitialCatalog = vDatabase,
                .UserID = vUsername,
                .Password = vPwd}
            Dim config = ConfigurationManager.OpenExeConfiguration(ConfigurationUserLevel.None)
            Dim connectionStringsSection = DirectCast(config.GetSection("connectionStrings"), ConnectionStringsSection)
            connectionStringsSection.ConnectionStrings("DatabaseConnection").ConnectionString = vBuilder.ToString
            config.Save()
            ConfigurationManager.RefreshSection("connectionStrings")
            Console.WriteLine("CurrentConnectionString: {0}", vBuilder.ConnectionString)
            'Store the session connectionstring in the singleton Class:
            CurrentSessionSettingsCls.Instance.ConnectionString = vBuilder.ConnectionString
            Return True
        Else
            Return False
        End If
    End Function





    ' Application-level events, such as Startup, Exit, and DispatcherUnhandledException
    ' can be handled in this file.

End Class
