﻿Namespace PasswordHelpers
    ''' <summary>
    ''' Helps to make the passwordbox bindable taken from:
    ''' https://www.wpftutorial.net/PasswordBox.html
    ''' </summary>
    Module PasswordHelper
        Public ReadOnly PasswordProperty As DependencyProperty = DependencyProperty.RegisterAttached("Password", GetType(String), GetType(PasswordHelper), New FrameworkPropertyMetadata(String.Empty, AddressOf OnPasswordPropertyChanged))
        Public ReadOnly AttachProperty As DependencyProperty = DependencyProperty.RegisterAttached("Attach", GetType(Boolean), GetType(PasswordHelper), New PropertyMetadata(False, AddressOf Attach))
        Private ReadOnly IsUpdatingProperty As DependencyProperty = DependencyProperty.RegisterAttached("IsUpdating", GetType(Boolean), GetType(PasswordHelper))

        Sub SetAttach(ByVal dp As DependencyObject, ByVal value As Boolean)
            dp.SetValue(AttachProperty, value)
        End Sub

        Function GetAttach(ByVal dp As DependencyObject) As Boolean
            Return CBool(dp.GetValue(AttachProperty))
        End Function

        Function GetPassword(ByVal dp As DependencyObject) As String
            Return CStr(dp.GetValue(PasswordProperty))
        End Function

        Sub SetPassword(ByVal dp As DependencyObject, ByVal value As String)
            dp.SetValue(PasswordProperty, value)
        End Sub

        Private Function GetIsUpdating(ByVal dp As DependencyObject) As Boolean
            Return CBool(dp.GetValue(IsUpdatingProperty))
        End Function

        Private Sub SetIsUpdating(ByVal dp As DependencyObject, ByVal value As Boolean)
            dp.SetValue(IsUpdatingProperty, value)
        End Sub

        Private Sub OnPasswordPropertyChanged(ByVal sender As DependencyObject, ByVal e As DependencyPropertyChangedEventArgs)
            Dim VPasswordBox As PasswordBox = TryCast(sender, PasswordBox)
            RemoveHandler VPasswordBox.PasswordChanged, AddressOf PasswordChanged
            If Not GetIsUpdating(VPasswordBox) Then VPasswordBox.Password = CStr(e.NewValue)
            AddHandler VPasswordBox.PasswordChanged, AddressOf PasswordChanged
        End Sub

        Private Sub Attach(ByVal sender As DependencyObject, ByVal e As DependencyPropertyChangedEventArgs)
            Dim VPasswordBox As PasswordBox = TryCast(sender, PasswordBox)
            If VPasswordBox Is Nothing Then Return

            If e.OldValue Then RemoveHandler VPasswordBox.PasswordChanged, AddressOf PasswordChanged

            If e.NewValue Then AddHandler VPasswordBox.PasswordChanged, AddressOf PasswordChanged
        End Sub

        Private Sub PasswordChanged(ByVal sender As Object, ByVal e As RoutedEventArgs)
            Dim passwordBox As PasswordBox = TryCast(sender, PasswordBox)
            SetIsUpdating(passwordBox, True)
            SetPassword(passwordBox, passwordBox.Password)
            SetIsUpdating(passwordBox, False)
        End Sub
    End Module
End Namespace
