﻿

Imports Model.MyERP2Model
Imports MyERP2.BL.Persistence

Namespace ViewModel
    ''' <summary>
    ''' Is a singleton class which holds all necessary infos of the currently logged in user.
    ''' </summary>
    Public Class CurrentlyLoggedinUser
        Private Shared ReadOnly vInstance As New Lazy(Of CurrentlyLoggedinUser)(Function() New CurrentlyLoggedinUser(), Threading.LazyThreadSafetyMode.ExecutionAndPublication)

        Public Shared ReadOnly Property Instance As CurrentlyLoggedinUser
            Get
                Return vInstance.Value
            End Get
        End Property

        Dim vCurrentUser As UserVM
        Public Property CurrentUser As UserVM
            Get
                Return vCurrentUser
            End Get
            Set(value As UserVM)
                vCurrentUser = value
                GetUserRights()
            End Set
        End Property

        Sub New()
        End Sub

        Sub New(_UserToStore As UserVM)
            CurrentUser = _UserToStore
        End Sub

        Dim vUserID As Guid
        Public Property UserID As Guid
            Get
                Return vUserID
            End Get
            Set(value As Guid)
                vUserID = value
                If CurrentUser Is Nothing Then GetUserVMByID()
            End Set
        End Property

        ''' <summary>
        ''' Gets an Object of Type UserVM with a given UserID
        ''' </summary>
        ''' <returns></returns>
        Private Function GetUserVMByID() As Boolean
            If UserID = Nothing Then Return False
            If CurrentUser IsNot Nothing Then Return False
            Using _UnitOfWork As New UnitOfWork(True)
                Dim vUser As User = _UnitOfWork.UsersRepo.Find(UserID)
                _UnitOfWork.UsersRepo.Attach(vUser)
                If vUser Is Nothing Then Return False
                _UnitOfWork.UsersRepo.LoadCollection(vUser, "NvUserUserGroup")
                _UnitOfWork.UsersRepo.LoadCollection(vUser, "NvUsersSettingsGrid")
                _UnitOfWork.UserGroupRepo.GetAll()
                CurrentUser = New UserVM(vUser)
                Debug.Print(CurrentUser.NvUserUserGroup.Count.ToString)
            End Using
            Return True
        End Function

        Private Function GetUserRights() As Boolean
            AvailableUserRights.Clear()
            If CurrentUser Is Nothing Then Return False
            For Each vItem As UserUserGroupVM In CurrentUser.NvUserUserGroup
                For Each vUserright As UserGroupRightVM In vItem.NvUserGroup.NvUserGroupRights
                    vAvailableUserRights.Add(vUserright.Authorization.ToLower)
                Next
            Next
            'Remove possible Duplicates:
            vAvailableUserRights = New List(Of String)(vAvailableUserRights.Distinct)
            Return True
        End Function

        Dim vAvailableUserRights As New List(Of String)
        Public Property AvailableUserRights As List(Of String)
            Get
                Return vAvailableUserRights
            End Get
            Private Set(value As List(Of String))
                vAvailableUserRights = value
            End Set
        End Property

    End Class
End Namespace
